##
##  socat.spec -- OpenPKG RPM Package Specification
##  Copyright (c) 2000-2024 OpenPKG Project <http://openpkg.org/>
##
##  Permission to use, copy, modify, and distribute this software for
##  any purpose with or without fee is hereby granted, provided that
##  the above copyright notice and this permission notice appear in all
##  copies.
##
##  THIS SOFTWARE IS PROVIDED ``AS IS'' AND ANY EXPRESSED OR IMPLIED
##  WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF
##  MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED.
##  IN NO EVENT SHALL THE AUTHORS AND COPYRIGHT HOLDERS AND THEIR
##  CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
##  SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT
##  LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF
##  USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND
##  ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
##  OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT
##  OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
##  SUCH DAMAGE.
##

#   package version
%define       V_major  1.8.0
%define       V_minor  1

#   package information
Name:         socat
Summary:      Socket Client
URL:          http://www.dest-unreach.org/socat/
Vendor:       Gerhard Rieger
Packager:     OpenPKG Project
Distribution: OpenPKG Community
Class:        BASE
Group:        Networking
License:      GPL
Version:      %{V_major}.%{V_minor}
Release:      20240826

#   package options
%option       with_readline yes
%option       with_ssl      yes

#   list of sources
Source0:      http://www.dest-unreach.org/socat/download/socat-%{V_major}.%{V_minor}.tar.bz2
Patch0:       socat.patch

#   build information
BuildPreReq:  OpenPKG, openpkg >= 20160101, gcc
PreReq:       OpenPKG, openpkg >= 20160101
%if "%{with_readline}" == "yes"
BuildPreReq:  readline
PreReq:       readline
%endif
%if "%{with_ssl}" == "yes"
BuildPreReq:  openssl
PreReq:       openssl
%endif

%description
    Socat is a relay for bi-directional data transfer between two
    independent data channels. Each of these data channels may be a
    file, pipe, device (terminal, modem, etc), socket (UNIX, IP4, IP6,
    raw, UDP, TCP), a file descriptor (stdin, etc), a program, or an
    arbitrary combination of two of these.

%track
    prog socat = {
        version   = %{version}
        url       = http://www.dest-unreach.org/socat/download/
        regex     = socat-(\d+\.\d+\.\d+(?:\.\d+))\.tar\.bz2
    }

%prep
    %setup -q -n socat-%{V_major}.%{V_minor}
    %patch -p0

%build
    CC="%{l_cc} %{l_cflags -O} %{l_cppflags}" \
    CFLAGS="%{l_cflags -O} %{l_cppflags}" \
    CPPFLAGS="%{l_cppflags}" \
    LDFLAGS="%{l_ldflags}" \
    ./configure \
        --prefix=%{l_prefix} \
        --mandir=%{l_prefix}/man \
        --enable-msglevel=debug \
%if "%{with_readline}" == "yes"
        --enable-readline \
%else
        --disable-readline \
%endif
%if "%{with_ssl}" == "yes"
        --enable-openssl \
%else
        --disable-openssl \
%endif
        --disable-dccp \
        --disable-libwrap

    %{l_make} %{l_mflags -O}

%install
    %{l_make} %{l_mflags} install DESTDIR=$RPM_BUILD_ROOT
    strip $RPM_BUILD_ROOT%{l_prefix}/bin/* >/dev/null 2>&1 || true
    %{l_rpmtool} files -v -ofiles -r$RPM_BUILD_ROOT %{l_files_std}

%files -f files

%clean

